@@ -15,7 +15,7 @@ const EXCHANGE_NAME: &str = "deribit";
 
 #[test_case(MarketType::InverseSwap, "BTC-PERPETUAL")]
 #[test_case(MarketType::InverseFuture, "BTC-24SEP21")]
-#[test_case(MarketType::EuropeanOption, "BTC-2JUL21-37000-C"; "inconclusive")]
+#[test_case(MarketType::EuropeanOption, "BTC-10SEP21-52000-C"; "inconclusive")]
 fn test_crawl_trade(market_type: MarketType, symbol: &str) {
     gen_test_code!(
         crawl_trade,
@@ -51,7 +51,7 @@ fn test_crawl_trade_all(market_type: MarketType) {
 
 #[test_case(MarketType::InverseSwap, "BTC-PERPETUAL")]
 #[test_case(MarketType::InverseFuture, "BTC-24SEP21")]
-#[test_case(MarketType::EuropeanOption, "BTC-2JUL21-37000-C")]
+#[test_case(MarketType::EuropeanOption, "BTC-10SEP21-52000-C")]
 fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
     gen_test_code!(
         crawl_l2_event,
@@ -64,7 +64,7 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
 
 #[test_case(MarketType::InverseSwap, "BTC-PERPETUAL")]
 #[test_case(MarketType::InverseFuture, "BTC-24SEP21")]
-#[test_case(MarketType::EuropeanOption, "BTC-2JUL21-37000-C")]
+#[test_case(MarketType::EuropeanOption, "BTC-10SEP21-52000-C")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
     gen_test_snapshot_code!(
         crawl_l2_snapshot,
@@ -77,7 +77,7 @@ fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
 
 #[test_case(MarketType::InverseSwap, "BTC-PERPETUAL")]
 #[test_case(MarketType::InverseFuture, "BTC-24SEP21")]
-#[test_case(MarketType::EuropeanOption, "BTC-2JUL21-37000-C")]
+#[test_case(MarketType::EuropeanOption, "BTC-10SEP21-52000-C")]
 fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
     gen_test_code!(
         crawl_ticker,
